---
title: Business
---

import { Cards } from 'nextra/components'

# Business

Business value and ROI of Django-CFG.

<Cards>
  <Cards.Card title="Reduce Development Costs" href="./reduce-django-development-costs" />
</Cards>
